define(['exports'], (function (exports) { 'use strict';

	var dep =
		/*#__PURE__*/
		(function() {
			return 0;
		})();

	exports.dep = dep;

}));
